@@ -11,6 +11,7 @@ import (
 	"github.com/derailed/k9s/internal/model1"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -27,7 +28,7 @@ func TestContainer(t *testing.T) {
 		Age:       makeAge(),
 	}
 	var r model1.Row
-	assert.Nil(t, c.Render(cres, "blee", &r))
+	require.NoError(t, c.Render(cres, "blee", &r))
 	assert.Equal(t, "fred", r.ID)
 	assert.Equal(t, model1.Fields{
 		"",
@@ -39,13 +40,14 @@ func TestContainer(t *testing.T) {
 		"0",
 		"off:off:off",
 		"10",
-		"20",
 		"20:20",
+		"50",
+		"50",
+		"20",
 		"100:100",
-		"50",
-		"50",
 		"20",
 		"20",
+		"0:0",
 		"",
 		"container is not ready",
 	},
@@ -54,19 +56,20 @@ func TestContainer(t *testing.T) {
 }
 
 func BenchmarkContainerRender(b *testing.B) {
-	var c render.Container
-
-	cres := render.ContainerRes{
-		Container: makeContainer(),
-		Status:    makeContainerStatus(),
-		MX:        makeContainerMetrics(),
-		Age:       makeAge(),
-	}
-	var r model1.Row
+	var (
+		c    render.Container
+		r    model1.Row
+		cres = render.ContainerRes{
+			Container: makeContainer(),
+			Status:    makeContainerStatus(),
+			MX:        makeContainerMetrics(),
+			Age:       makeAge(),
+		}
+	)
 
 	b.ReportAllocs()
 	b.ResetTimer()
-	for n := 0; n < b.N; n++ {
+	for range b.N {
 		_ = c.Render(cres, "blee", &r)
 	}
 }
