@@ -140,7 +140,7 @@ func (p *Pod) Render(o any, _ string, row *model1.Row) error {
 	if p.specs.isEmpty() {
 		return nil
 	}
-	cols, err := p.specs.realize(pwm.Raw, defaultPodHeader, row)
+	cols, err := p.specs.realize(pwm.Raw.DeepCopy(), defaultPodHeader, row)
 	if err != nil {
 		return err
 	}
