@@ -15,7 +15,7 @@ import (
 func TestErrorDialog(t *testing.T) {
 	p := ui.NewPages()
 
-	ShowError(config.Dialog{}, p, "Yo")
+	ShowError(new(config.Dialog), p, "Yo")
 
 	d := p.GetPrimitive(dialogKey).(*tview.ModalForm)
 	assert.NotNil(t, d)
