@@ -13,7 +13,7 @@ import (
 )
 
 func TestIndicatorReset(t *testing.T) {
-	i := ui.NewStatusIndicator(ui.NewApp(mock.NewMockConfig(), ""), config.NewStyles())
+	i := ui.NewStatusIndicator(ui.NewApp(mock.NewMockConfig(t), ""), config.NewStyles())
 	i.SetPermanent("Blee")
 	i.Info("duh")
 	i.Reset()
@@ -22,21 +22,21 @@ func TestIndicatorReset(t *testing.T) {
 }
 
 func TestIndicatorInfo(t *testing.T) {
-	i := ui.NewStatusIndicator(ui.NewApp(mock.NewMockConfig(), ""), config.NewStyles())
+	i := ui.NewStatusIndicator(ui.NewApp(mock.NewMockConfig(t), ""), config.NewStyles())
 	i.Info("Blee")
 
 	assert.Equal(t, "[lawngreen::b] <Blee> \n", i.GetText(false))
 }
 
 func TestIndicatorWarn(t *testing.T) {
-	i := ui.NewStatusIndicator(ui.NewApp(mock.NewMockConfig(), ""), config.NewStyles())
+	i := ui.NewStatusIndicator(ui.NewApp(mock.NewMockConfig(t), ""), config.NewStyles())
 	i.Warn("Blee")
 
 	assert.Equal(t, "[mediumvioletred::b] <Blee> \n", i.GetText(false))
 }
 
 func TestIndicatorErr(t *testing.T) {
-	i := ui.NewStatusIndicator(ui.NewApp(mock.NewMockConfig(), ""), config.NewStyles())
+	i := ui.NewStatusIndicator(ui.NewApp(mock.NewMockConfig(t), ""), config.NewStyles())
 	i.Err("Blee")
 
 	assert.Equal(t, "[orangered::b] <Blee> \n", i.GetText(false))
