@@ -410,7 +410,8 @@ func resumeShellIn(a *App, c model.Component, path, co string) {
 func shellIn(a *App, fqn, co string) error {
 	platform, err := getPodOS(a.factory, fqn)
 	if err != nil {
-		return err
+		slog.Warn("OS detection failed (assuming linux)", slogs.Error, err)
+		platform = "linux"
 	}
 
 	args := computeShellArgs(fqn, co, a.Conn().Config().Flags(), platform)
