@@ -17,7 +17,7 @@ import (
 type Namespace struct{}
 
 // Render renders an xray node.
-func (n *Namespace) Render(ctx context.Context, ns string, o interface{}) error {
+func (n *Namespace) Render(ctx context.Context, ns string, o any) error {
 	raw, ok := o.(*unstructured.Unstructured)
 	if !ok {
 		return fmt.Errorf("expected NamespaceWithMetrics, but got %T", o)
@@ -29,10 +29,10 @@ func (n *Namespace) Render(ctx context.Context, ns string, o interface{}) error
 		return err
 	}
 
-	root := NewTreeNode("v1/namespaces", client.FQN(client.ClusterScope, nss.Name))
+	root := NewTreeNode(client.NsGVR, client.FQN(client.ClusterScope, nss.Name))
 	parent, ok := ctx.Value(KeyParent).(*TreeNode)
 	if !ok {
-		return fmt.Errorf("Expecting a TreeNode but got %T", ctx.Value(KeyParent))
+		return fmt.Errorf("expecting a TreeNode but got %T", ctx.Value(KeyParent))
 	}
 	parent.Add(root)
 
