@@ -8,8 +8,10 @@ import (
 	"testing"
 
 	"github.com/derailed/k9s/internal"
+	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/xray"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
@@ -32,14 +34,16 @@ func TestReplicaSetRender(t *testing.T) {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
 			f := makeFactory()
-			f.rows = map[string][]runtime.Object{"v1/pods": {load(t, "po")}}
+			f.rows = map[*client.GVR][]runtime.Object{
+				client.PodGVR: {load(t, "po")},
+			}
 
 			o := load(t, u.file)
-			root := xray.NewTreeNode("replicasets", "replicasets")
+			root := xray.NewTreeNode(client.RsGVR, "replicasets")
 			ctx := context.WithValue(context.Background(), xray.KeyParent, root)
 			ctx = context.WithValue(ctx, internal.KeyFactory, f)
 
-			assert.Nil(t, re.Render(ctx, "", o))
+			require.NoError(t, re.Render(ctx, "", o))
 			assert.Equal(t, u.level1, root.CountChildren())
 			assert.Equal(t, u.level2, root.Children[0].CountChildren())
 		})
